@@ -1,12 +1,7 @@
 # Test::DistManifest
 #  Tests that your manifest matches the distribution as it exists.
 #
-# $Id: DistManifest.pm 7095 2009-05-15 04:10:13Z FREQUENCY@cpan.org $
-#
-# Copyright (C) 2008-2009 by Jonathan Yu <frequency@cpan.org>
-#
-# This package is distributed with the same licensing terms as Perl itself.
-# For additional information, please read the included `LICENSE' file.
+# $Id: DistManifest.pm 8222 2009-07-26 00:08:57Z FREQUENCY@cpan.org $
 
 package Test::DistManifest;
 
@@ -16,15 +11,15 @@ use Carp ();
 
 =head1 NAME
 
-Test::DistManifest - Verify MANIFEST/MANIFEST.SKIP as an author test
+Test::DistManifest - Author test that validates a package MANIFEST
 
 =head1 VERSION
 
-Version 1.2.1 ($Id: DistManifest.pm 7095 2009-05-15 04:10:13Z FREQUENCY@cpan.org $)
+Version 1.2.3 ($Id: DistManifest.pm 8222 2009-07-26 00:08:57Z FREQUENCY@cpan.org $)
 
 =cut
 
-use version; our $VERSION = qv('1.2.1');
+use version; our $VERSION = qv('1.2.3');
 
 =head1 EXPORTS
 
@@ -72,7 +67,7 @@ sub import {
   my $caller = caller;
 
   {
-    ## no critic (ProhibitNoStrict, ProhibitNoisyQuotes)
+    ## no critic (ProhibitNoStrict)
     no strict 'refs';
     for my $func (@EXPORTS) {
       *{$caller . '::' . $func} = \&{$func};
@@ -99,8 +94,8 @@ Everything in B<MANIFEST> exists
 
 =item 2
 
-Everything in the package is listed in B<MANIFEST>, or subsequently matches a
-regular expression mask in B<MANIFEST.SKIP>
+Everything in the package is listed in B<MANIFEST>, or subsequently matches
+a regular expression mask in B<MANIFEST.SKIP>
 
 =item 3
 
@@ -113,6 +108,9 @@ so as to avoid an unsatisfiable dependency conditions
 
   use Test::More;
 
+  # This is the common idiom for author test modules like this, but see
+  # the full example in examples/checkmanifest.t and, more importantly,
+  # Adam Kennedy's article: http://use.perl.org/~Alias/journal/38822
   eval 'use Test::DistManifest';
   if ($@) {
     plan skip_all => 'Test::DistManifest required to test MANIFEST';
@@ -172,9 +170,9 @@ or from other shell scripts as:
 
   export MANIFEST_WARN_ONLY=1
 
-Note that parsing errors in each file (B<MANIFEST> and B<MANIFEST.SKIP>) and
-circular dependencies will always be considered fatal. The author is not aware
-of any other use cases where other behaviour would be useful.
+Note that parsing errors in each file (B<MANIFEST> and B<MANIFEST.SKIP>)
+and circular dependencies will always be considered fatal. The author is
+not aware of any cases where other behaviour would be useful.
 
 =cut
 
@@ -329,14 +327,14 @@ distribution, or accidentally moves it.
 
 =item 4
 
-Check which files are specified in both B<MANIFEST> and B<MANIFEST.SKIP>. This
-is clearly an unsatisfiable condition, since the file in question cannot be
-expected to be included while also simultaneously ignored.
+Check which files are specified in both B<MANIFEST> and B<MANIFEST.SKIP>.
+This is clearly an unsatisfiable condition, since the file in question
+cannot be expected to be included while also simultaneously ignored.
 
 =back
 
-If you want to run tests on multiple different MANIFEST files, you can simply
-pass 'no_plan' to the import function, like so:
+If you want to run tests on multiple different MANIFEST files, you can
+simply pass 'no_plan' to the import function, like so:
 
   use Test::DistManifest 'no_plan';
 
@@ -346,9 +344,9 @@ pass 'no_plan' to the import function, like so:
   manifest_ok('MANIFEST.OTHER', 'MANIFEST.SKIP');
 
 I doubt this will be useful to users of this module. However, this is used
-internally for testing and it might be helpful to you. You can also plan more
-tests, but keep in mind that the idea of "3 internal tests"  may change in the
-future.
+internally for testing and it might be helpful to you. You can also plan
+more tests, but keep in mind that the idea of "3 internal tests" may change
+in the future.
 
 Example code:
 
@@ -371,9 +369,9 @@ Your name here ;-)
 =item * Thanks to Adam Kennedy E<lt>adamk@cpan.orgE<gt>, developer of
 Module::Manifest, which is used in this module.
 
-=item * Thanks to Apocalypse E<lt>apocal@cpan.orgE<gt>, for helping me track
-down an obscure bug caused by circular dependencies: when files are expected
-by MANIFEST but explictly skipped by MANIFEST.SKIP.
+=item * Thanks to Apocalypse E<lt>apocal@cpan.orgE<gt>, for helping me
+track down an obscure bug caused by circular dependencies: when files are
+expected by MANIFEST but explictly skipped by MANIFEST.SKIP.
 
 =back
 
@@ -407,10 +405,6 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Dist-Manifest>
 
 L<http://cpants.perl.org/dist/overview/Test-DistManifest>
 
-=item * Test::DistManifest's Subversion repository
-
-L<http://svn.ali.as/cpan/trunk/Test-DistManifest>
-
 =back
 
 =head1 REPOSITORY
@@ -419,20 +413,20 @@ You can access the most recent development version of this module at:
 
 L<http://svn.ali.as/cpan/trunk/Test-DistManifest>
 
-If you are a CPAN developer and would like to make modifications to the code
-base, please contact Adam Kennedy E<lt>adamk@cpan.orgE<gt>, the repository
-administrator. I only ask that you contact me first to discuss the changes you
-wish to make to the distribution.
+If you are a CPAN developer and would like to make modifications to the
+code base, please contact Adam Kennedy E<lt>adamk@cpan.orgE<gt>, the
+repository administrator. I only ask that you contact me first to discuss
+the changes you wish to make to the distribution.
 
 =head1 FEEDBACK
 
-Please send relevant comments, rotten tomatoes and suggestions directly to the
-maintainer noted above.
+Please send relevant comments, rotten tomatoes and suggestions directly to
+the maintainer noted above.
 
 If you have a bug report or feature request, please file them on the CPAN
-Request Tracker at L<http://rt.cpan.org>. If you are able to submit your bug
-report in the form of failing unit tests, you are B<strongly> encouraged to do
-so.
+Request Tracker at L<http://rt.cpan.org>. If you are able to submit your
+bug report in the form of failing unit tests, you are B<strongly> encouraged
+to do so.
 
 =head1 SEE ALSO
 
@@ -465,28 +459,39 @@ the module; the emphasis should be on generating helpful error messages.
 
 =back
 
+=head1 QUALITY ASSURANCE METRICS
+
+=head2 TEST COVERAGE
+  
+  ----------------------- ------ ------ ------ ------ ------ ------
+  File                    stmt   bran   cond   sub    pod    total
+  ----------------------- ------ ------ ------ ------ ------ ------
+  Test/DistManifest.pm    96.1   95.8   100.0  100.0  100.0  96.8
+  Total                   96.1   95.8   100.0  100.0  100.0  96.8
+
 =head1 LICENSE
 
 Copyright (C) 2008-2009 by Jonathan Yu <frequency@cpan.org>
 
-This package is distributed under the same terms as Perl itself. Please see
-the LICENSE file included in this distribution for full details of these
-terms.
+This package is distributed under the same terms as Perl itself. Please
+see the F<LICENSE> file included in this distribution for full details of
+these terms.
 
 =head1 DISCLAIMER OF WARRANTY
 
-This software is provided by the copyright holders and contributors "AS IS"
-and ANY EXPRESS OR IMPLIED WARRANTIES, including, but not limited to, the
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-DISCLAIMED.
+This software is provided by the copyright holders and contributors 
+"AS IS" and ANY EXPRESS OR IMPLIED WARRANTIES, including, but not 
+limited to, the IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
+A PARTICULAR PURPOSE ARE DISCLAIMED. 
 
-In no event shall the copyright owner or contributors be liable for any
-direct, indirect, incidental, special, exemplary or consequential damages
-(including, but not limited to, procurement of substitute goods or services;
-loss of use, data or profits; or business interruption) however caused and on
-any theory of liability, whether in contract, strict liability or tort
-(including negligence or otherwise) arising in any way out of the use of this
-software, even if advised of the possibility of such damage.
+In no event shall the copyright owner or contributors be liable for 
+any direct, indirect, incidental, special, exemplary or consequential 
+damages (including, but not limited to, procurement of substitute 
+goods or services; loss of use, data or profits; or business 
+interruption) however caused and on any theory of liability, whether 
+in contract, strict liability or tort (including negligence or 
+otherwise) arising in any way out of the use of this software, even if 
+advised of the possibility of such damage. 
 
 =cut
 
